@@ -8,7 +8,7 @@ import wsaccel
 import sys
 import ScratchEncoder
 ws = websocket.WebSocket()
-encoder = ScratchEncoder()
+encoder = ScratchEncoder.Encoder()
 
 
 class s2py():
